<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>KdeNotify</name>
    <message>
        <location filename="../kdenotify.cpp" line="122"/>
        <source>Qmmp now playing:</source>
        <translation>Qmmp sekarang memainkan:</translation>
    </message>
</context>
<context>
    <name>KdeNotifyFactory</name>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="29"/>
        <source>KDE notification plugin</source>
        <translation>Plugin pemberitahuan KDE</translation>
    </message>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="49"/>
        <source>About KDE Notification Plugin</source>
        <translation>Tentang Plugin Pemberitahuan KDE</translation>
    </message>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="50"/>
        <source>KDE notification plugin for Qmmp</source>
        <translation>Plugin pemberitahuan KDE untuk Qmmp</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>KDE 4 Notification Plugin Settings</source>
        <translation>Setelan Plugin Pemberitahuan KDE 4</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Options</source>
        <translation>Pilihan</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Notification delay:</source>
        <translation>Tundaan pemberitahuan:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>s</source>
        <translation>d</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Update visible notification instead create new</source>
        <translation>Perbarui pemberitahuan yang terlihat bukannya menciptakan baru</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="88"/>
        <source>Appearance</source>
        <translation>Tampilan</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Show covers</source>
        <translation>Tampakkan sampul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Edit template</source>
        <translation>Edit template</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="75"/>
        <source>Notification Template</source>
        <translation>Template Pemberitahuan</translation>
    </message>
</context>
</TS>
